# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: price_index/price_index.proto
# Protobuf Python Version: 6.30.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    30,
    2,
    '',
    'price_index/price_index.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import marketdata_pb2 as marketdata__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1dprice_index/price_index.proto\x12\x13marketdata_messages\x1a\x10marketdata.proto\"4\n\x08\x43urrency\x12\n\n\x02Id\x18\x01 \x01(\t\x12\x0c\n\x04Name\x18\x02 \x01(\t\x12\x0e\n\x06Symbol\x18\x03 \x01(\t\"\x93\x01\n\x06Market\x12\n\n\x02Id\x18\x01 \x01(\t\x12\x0f\n\x07Network\x18\x02 \x01(\t\x12\x12\n\nNetworkBid\x18\x03 \x01(\t\x12\x0c\n\x04Name\x18\x04 \x01(\t\x12\x0f\n\x07\x41\x64\x64ress\x18\x05 \x01(\t\x12\x10\n\x08Protocol\x18\x06 \x01(\t\x12\x16\n\x0eProtocolFamily\x18\x07 \x01(\t\x12\x0f\n\x07Program\x18\x08 \x01(\t\"P\n\x07\x41mounts\x12\x0c\n\x04\x42\x61se\x18\x01 \x01(\x02\x12\r\n\x05Quote\x18\x02 \x01(\x02\x12\x0b\n\x03Usd\x18\x03 \x01(\x02\x12\x1b\n\x13\x42\x61seAttributedToUsd\x18\x04 \x01(\x02\"l\n\x05Quote\x12\x34\n\rQuoteCurrency\x18\x01 \x01(\x0b\x32\x1d.marketdata_messages.Currency\x12-\n\x07\x41mounts\x18\x02 \x01(\x0b\x32\x1c.marketdata_messages.Amounts\"<\n\x0cTimeInterval\x12\x10\n\x08\x44uration\x18\x01 \x01(\r\x12\r\n\x05Start\x18\x02 \x01(\r\x12\x0b\n\x03\x45nd\x18\x03 \x01(\r\"N\n\x04Ohlc\x12\x0c\n\x04Open\x18\x01 \x01(\x02\x12\r\n\x05\x43lose\x18\x02 \x01(\x02\x12\x0c\n\x04High\x18\x03 \x01(\x02\x12\x0b\n\x03Low\x18\x04 \x01(\x02\x12\x0e\n\x06Volume\x18\x05 \x01(\x02\"\x9d\x02\n\x13PriceByTimeInterval\x12\x37\n\x0cTimeInterval\x18\x01 \x01(\x0b\x32!.marketdata_messages.TimeInterval\x12-\n\x07\x41mounts\x18\x02 \x01(\x0b\x32\x1c.marketdata_messages.Amounts\x12\x11\n\tMeanPrice\x18\x03 \x01(\x02\x12\x1b\n\x13SimpleMovingAverage\x18\x04 \x01(\x02\x12#\n\x1bWeightedSimpleMovingAverage\x18\x05 \x01(\x02\x12 \n\x18\x45xponentialMovingAverage\x18\x06 \x01(\x02\x12\'\n\x04Ohlc\x18\x07 \x01(\x0b\x32\x19.marketdata_messages.Ohlc\"\xa0\x01\n\rPriceByVolume\x12\x14\n\x0cTargetVolume\x18\x01 \x01(\x02\x12\x37\n\x0cTimeInterval\x18\x02 \x01(\x0b\x32!.marketdata_messages.TimeInterval\x12-\n\x07\x41mounts\x18\x03 \x01(\x0b\x32\x1c.marketdata_messages.Amounts\x12\x11\n\tMeanPrice\x18\x04 \x01(\x02\"(\n\x0f\x45stimatedPrices\x12\x15\n\rAdaptivePrice\x18\x01 \x01(\x02\"\xf6\x01\n\x0bPriceUpdate\x12*\n\x06Quotes\x18\x01 \x03(\x0b\x32\x1a.marketdata_messages.Quote\x12\x46\n\x14PriceByTimeIntervals\x18\x02 \x03(\x0b\x32(.marketdata_messages.PriceByTimeInterval\x12:\n\x0ePriceByVolumes\x18\x03 \x03(\x0b\x32\".marketdata_messages.PriceByVolume\x12\x37\n\tEstimates\x18\x04 \x01(\x0b\x32$.marketdata_messages.EstimatedPrices\"x\n\x0e\x43urrencyUpdate\x12/\n\x08\x43urrency\x18\x01 \x01(\x0b\x32\x1d.marketdata_messages.Currency\x12\x35\n\x0bPriceUpdate\x18\x02 \x01(\x0b\x32 .marketdata_messages.PriceUpdate\"\xa0\x01\n\x0bTokenUpdate\x12/\n\x08\x43urrency\x18\x01 \x01(\x0b\x32\x1d.marketdata_messages.Currency\x12)\n\x05Token\x18\x02 \x01(\x0b\x32\x1a.marketdata_messages.Token\x12\x35\n\x0bPriceUpdate\x18\x03 \x01(\x0b\x32 .marketdata_messages.PriceUpdate\"\xf6\x02\n\nPairUpdate\x12/\n\x08\x43urrency\x18\x01 \x01(\x0b\x32\x1d.marketdata_messages.Currency\x12\x34\n\rQuoteCurrency\x18\x02 \x01(\x0b\x32\x1d.marketdata_messages.Currency\x12)\n\x05Token\x18\x03 \x01(\x0b\x32\x1a.marketdata_messages.Token\x12.\n\nQuoteToken\x18\x04 \x01(\x0b\x32\x1a.marketdata_messages.Token\x12+\n\x06Market\x18\x05 \x01(\x0b\x32\x1b.marketdata_messages.Market\x12\x35\n\x0bPriceUpdate\x18\x06 \x01(\x0b\x32 .marketdata_messages.PriceUpdate\x12\x42\n\x18PriceUpdateInQuoteTokens\x18\x07 \x01(\x0b\x32 .marketdata_messages.PriceUpdate\"\xcd\x01\n\x11PriceIndexMessage\x12\x0c\n\x04Time\x18\x01 \x01(\x04\x12<\n\x0f\x43urrencyUpdates\x18\x02 \x03(\x0b\x32#.marketdata_messages.CurrencyUpdate\x12\x36\n\x0cTokenUpdates\x18\x03 \x03(\x0b\x32 .marketdata_messages.TokenUpdate\x12\x34\n\x0bPairUpdates\x18\x04 \x03(\x0b\x32\x1f.marketdata_messages.PairUpdateb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'price_index.price_index_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_CURRENCY']._serialized_start=72
  _globals['_CURRENCY']._serialized_end=124
  _globals['_MARKET']._serialized_start=127
  _globals['_MARKET']._serialized_end=274
  _globals['_AMOUNTS']._serialized_start=276
  _globals['_AMOUNTS']._serialized_end=356
  _globals['_QUOTE']._serialized_start=358
  _globals['_QUOTE']._serialized_end=466
  _globals['_TIMEINTERVAL']._serialized_start=468
  _globals['_TIMEINTERVAL']._serialized_end=528
  _globals['_OHLC']._serialized_start=530
  _globals['_OHLC']._serialized_end=608
  _globals['_PRICEBYTIMEINTERVAL']._serialized_start=611
  _globals['_PRICEBYTIMEINTERVAL']._serialized_end=896
  _globals['_PRICEBYVOLUME']._serialized_start=899
  _globals['_PRICEBYVOLUME']._serialized_end=1059
  _globals['_ESTIMATEDPRICES']._serialized_start=1061
  _globals['_ESTIMATEDPRICES']._serialized_end=1101
  _globals['_PRICEUPDATE']._serialized_start=1104
  _globals['_PRICEUPDATE']._serialized_end=1350
  _globals['_CURRENCYUPDATE']._serialized_start=1352
  _globals['_CURRENCYUPDATE']._serialized_end=1472
  _globals['_TOKENUPDATE']._serialized_start=1475
  _globals['_TOKENUPDATE']._serialized_end=1635
  _globals['_PAIRUPDATE']._serialized_start=1638
  _globals['_PAIRUPDATE']._serialized_end=2012
  _globals['_PRICEINDEXMESSAGE']._serialized_start=2015
  _globals['_PRICEINDEXMESSAGE']._serialized_end=2220
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: evm/dex_pool_block_message.proto
# Protobuf Python Version: 6.30.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    30,
    2,
    '',
    'evm/dex_pool_block_message.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from evm import block_message_pb2 as evm_dot_block__message__pb2
from evm import dex_block_message_pb2 as evm_dot_dex__block__message__pb2
from evm import token_block_message_pb2 as evm_dot_token__block__message__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n evm/dex_pool_block_message.proto\x12\x0c\x65vm_messages\x1a\x17\x65vm/block_message.proto\x1a\x1b\x65vm/dex_block_message.proto\x1a\x1d\x65vm/token_block_message.proto\"\xdf\x01\n\x13\x44\x65xPoolBlockMessage\x12\"\n\x05\x43hain\x18\x01 \x01(\x0b\x32\x13.evm_messages.Chain\x12)\n\x06Header\x18\x02 \x01(\x0b\x32\x19.evm_messages.BlockHeader\x12:\n\nPoolEvents\x18\x05 \x03(\x0b\x32&.evm_messages.PoolLiquidityChangeEvent\x12\x30\n\x08L1Header\x18\x06 \x01(\x0b\x32\x19.evm_messages.BlockHeaderH\x00\x88\x01\x01\x42\x0b\n\t_L1Header\"\xf2\x02\n\x18PoolLiquidityChangeEvent\x12:\n\x11TransactionHeader\x18\x01 \x01(\x0b\x32\x1f.evm_messages.TransactionHeader\x12\x35\n\x14TransactionSignature\x18\x02 \x01(\x0b\x32\x17.evm_messages.Signature\x12\x11\n\tCallIndex\x18\x03 \x01(\x04\x12\x10\n\x08LogIndex\x18\x04 \x01(\x04\x12\x0e\n\x06HasLog\x18\x05 \x01(\x08\x12\"\n\x03\x44\x65x\x18\x06 \x01(\x0b\x32\x15.evm_messages.DexInfo\x12.\n\tLiquidity\x18\x08 \x01(\x0b\x32\x1b.evm_messages.PoolLiquidity\x12\x34\n\x0ePoolPriceTable\x18\t \x01(\x0b\x32\x1c.evm_messages.PoolPriceTable\x12$\n\x04Pool\x18\x0b \x01(\x0b\x32\x16.evm_messages.PoolInfo\"\xb0\x01\n\x08PoolInfo\x12\x15\n\rSmartContract\x18\x01 \x01(\x0c\x12*\n\tCurrencyA\x18\x02 \x01(\x0b\x32\x17.evm_messages.TokenInfo\x12*\n\tCurrencyB\x18\x03 \x01(\x0b\x32\x17.evm_messages.TokenInfo\x12%\n\x04Pair\x18\x04 \x01(\x0b\x32\x17.evm_messages.TokenInfo\x12\x0e\n\x06PoolId\x18\x05 \x01(\x0c\"A\n\rPoolLiquidity\x12\x17\n\x0f\x41mountCurrencyA\x18\x01 \x01(\x0c\x12\x17\n\x0f\x41mountCurrencyB\x18\x02 \x01(\x0c\"b\n\tPoolPrice\x12\x1b\n\x13SlippageBasisPoints\x18\x01 \x01(\r\x12\x13\n\x0bMaxAmountIn\x18\x02 \x01(\x0c\x12\x14\n\x0cMinAmountOut\x18\x03 \x01(\x0c\x12\r\n\x05Price\x18\x04 \x01(\x02\"\x90\x01\n\x0ePoolPriceTable\x12+\n\nAtoBPrices\x18\x01 \x03(\x0b\x32\x17.evm_messages.PoolPrice\x12+\n\nBtoAPrices\x18\x02 \x03(\x0b\x32\x17.evm_messages.PoolPrice\x12\x11\n\tAtoBPrice\x18\x03 \x01(\x02\x12\x11\n\tBtoAPrice\x18\x04 \x01(\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'evm.dex_pool_block_message_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_DEXPOOLBLOCKMESSAGE']._serialized_start=136
  _globals['_DEXPOOLBLOCKMESSAGE']._serialized_end=359
  _globals['_POOLLIQUIDITYCHANGEEVENT']._serialized_start=362
  _globals['_POOLLIQUIDITYCHANGEEVENT']._serialized_end=732
  _globals['_POOLINFO']._serialized_start=735
  _globals['_POOLINFO']._serialized_end=911
  _globals['_POOLLIQUIDITY']._serialized_start=913
  _globals['_POOLLIQUIDITY']._serialized_end=978
  _globals['_POOLPRICE']._serialized_start=980
  _globals['_POOLPRICE']._serialized_end=1078
  _globals['_POOLPRICETABLE']._serialized_start=1081
  _globals['_POOLPRICETABLE']._serialized_end=1225
# @@protoc_insertion_point(module_scope)
